#
# spec file for package vkbasalt-cli
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global appid io.gitlab.theevilskeleton.vkbasalt_cli
%global appname vkbasalt-cli
%global cliname vkbasalt

%define pythons %primary_python

Name:           vkbasalt-cli
Version:        3.1.1
Release:        2.3
Summary:        Command-line utility for vkBasalt
License:        LGPL-3.0-only
URL:            https://gitlab.com/TheEvilSkeleton/vkbasalt-cli
Source0:        https://gitlab.com/TheEvilSkeleton/vkbasalt-cli/-/archive/v%{version}/%{appname}-v%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch

%description
vkbasalt-cli (filename vkbasalt) is a CLI utility and library in conjunction with vkBasalt. This makes generating configuration files or running vkBasalt with games easier. This is mainly convenient in environments where integrating vkBasalt is wishful, for example a GUI application. Integrating vkbasalt-cli allows a front-end to easily generate and use specific configurations on the fly, without asking the user to manually write a configuration file

%prep
%autosetup -n %{appname}-v%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# No tests available, even upstream

%files
%license COPYING
%doc README.md
%{_bindir}/vkbasalt
%{python_sitelib}/vkbasalt
%{python_sitelib}/vkbasalt_cli-%{version}*-info

%changelog
* Fri Feb  9 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Fix mix-up between python single-spec usage and hardcoded
  python3-* BuildRequires:
  + Set pythons to primary_python: this package is a cli tool
    and not providing python modules.
  + Fix BuildRequires to use python_module: limited by pythons
    being set to primary_python, this will only pull in one flavor.
  + Doing so allows us to keep the regular pyproject_* macros in
    place.
- Add python-setuptools BuildRequires: used to be dragged in
  indirectly.
* Wed Apr 12 2023 Imo Hester <vortex@z-ray.de>
- Fixed binary naming
* Wed Apr 12 2023 Imo Hester <vortex@z-ray.de>
- Removed update-alternatives
* Wed Apr 12 2023 Imo Hester <vortex@z-ray.de>
- Drop build for Python3.9 and 3.11
- Removed sub modules directive
* Wed Apr 12 2023 Imo Hester <vortex@z-ray.de>
- Licensed changed to LGPL-3.0-only
- Application name changed to vkbasalt-cli
- Removed unused build dependencies
* Thu Mar 30 2023 Imo Hester <vortex@z-ray.de>
- Removed python module redefinition as < 15.0 is not targeted
* Thu Dec 22 2022 Imo Hester <vortex@z-ray.de>
- Update to version 3.1.1
  * Remove Meson support
  * Fix CLI for setup.py
  * Remove appstream
* Sun Nov 20 2022 Imo Hester <vortex@z-ray.de>
- Update to version 3.1.0
  * Change meson output from `vkbasalt-cli` to `vkbasalt`. This means users will have to run the command using `vkbasalt`
  * Update documentation
  * Update metadata file
- Update to version 3.0
  * Add setup.py
  * Move directories
  * Relicense CLI front-end to GPLv3
  * Update headers
  * Update documentation
  * Improve sentences
- Update to version 2.0
  * Dump everything from bottles
* Sun Nov 20 2022 Imo Hester <vortex@z-ray.de>
- Initial obs package
- Update to version 0.1.1
  * Fix metainfo file
- Update to version 0.1
  * Initial release
